Props

Struct Props 

pub struct Props<STATE: RouterState, SW: Switch + PartialEq + Clone + 'static> {
    pub render: Render<SW, STATE>,
    pub redirect: Option<Redirect<SW, STATE>>,
}
Properties for Router.

Fields

render: Render<SW, STATE>

Render function that takes a Switch and produces Html

redirect: Option<Redirect<SW, STATE>>

Optional redirect function that will convert the route to a known switch variant if explicit matching fails. This should mostly be used to handle 404s and redirection. It is not strictly necessary as your Switch is capable of handling unknown routes using #[to="/{*:any}"].